# Generated by Django 3.0.7 on 2020-07-01 11:02

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='UserFiles',
            fields=[
                ('username', models.CharField(max_length=64)),
                ('file_path', models.TextField()),
                ('file_dpu', models.CharField(max_length=255, primary_key=True, serialize=False)),
            ],
        ),
        migrations.AddIndex(
            model_name='userfiles',
            index=models.Index(fields=['username'], name='userfiles_username_idx'),
        ),
    ]
