# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CredCommon.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='CredCommon.proto',
  package='org.apache.airavata.mft.common',
  syntax='proto3',
  serialized_options=b'P\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x43redCommon.proto\x12\x1eorg.apache.airavata.mft.common\"\x1e\n\rUserTokenAuth\x12\r\n\x05token\x18\x01 \x01(\t\"@\n\tAgentAuth\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0f\n\x07\x61gentId\x18\x02 \x01(\t\x12\x13\n\x0b\x61gentSecret\x18\x03 \x01(\t\"\xcb\x01\n\x0c\x44\x65legateAuth\x12\x0e\n\x06userId\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x02 \x01(\t\x12\x14\n\x0c\x63lientSecret\x18\x03 \x01(\t\x12P\n\nproperties\x18\x04 \x03(\x0b\x32<.org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\tAuthToken\x12\x46\n\ruserTokenAuth\x18\x01 \x01(\x0b\x32-.org.apache.airavata.mft.common.UserTokenAuthH\x00\x12>\n\tagentAuth\x18\x02 \x01(\x0b\x32).org.apache.airavata.mft.common.AgentAuthH\x00\x12\x44\n\x0c\x64\x65legateAuth\x18\x03 \x01(\x0b\x32,.org.apache.airavata.mft.common.DelegateAuthH\x00\x42\x0f\n\rauthMechanismB\x02P\x01\x62\x06proto3'
)




_USERTOKENAUTH = _descriptor.Descriptor(
  name='UserTokenAuth',
  full_name='org.apache.airavata.mft.common.UserTokenAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='org.apache.airavata.mft.common.UserTokenAuth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=82,
)


_AGENTAUTH = _descriptor.Descriptor(
  name='AgentAuth',
  full_name='org.apache.airavata.mft.common.AgentAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='org.apache.airavata.mft.common.AgentAuth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentId', full_name='org.apache.airavata.mft.common.AgentAuth.agentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentSecret', full_name='org.apache.airavata.mft.common.AgentAuth.agentSecret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=148,
)


_DELEGATEAUTH_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=354,
)

_DELEGATEAUTH = _descriptor.Descriptor(
  name='DelegateAuth',
  full_name='org.apache.airavata.mft.common.DelegateAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='org.apache.airavata.mft.common.DelegateAuth.userId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='org.apache.airavata.mft.common.DelegateAuth.clientId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientSecret', full_name='org.apache.airavata.mft.common.DelegateAuth.clientSecret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='org.apache.airavata.mft.common.DelegateAuth.properties', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELEGATEAUTH_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=354,
)


_AUTHTOKEN = _descriptor.Descriptor(
  name='AuthToken',
  full_name='org.apache.airavata.mft.common.AuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userTokenAuth', full_name='org.apache.airavata.mft.common.AuthToken.userTokenAuth', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentAuth', full_name='org.apache.airavata.mft.common.AuthToken.agentAuth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delegateAuth', full_name='org.apache.airavata.mft.common.AuthToken.delegateAuth', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authMechanism', full_name='org.apache.airavata.mft.common.AuthToken.authMechanism',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=357,
  serialized_end=591,
)

_DELEGATEAUTH_PROPERTIESENTRY.containing_type = _DELEGATEAUTH
_DELEGATEAUTH.fields_by_name['properties'].message_type = _DELEGATEAUTH_PROPERTIESENTRY
_AUTHTOKEN.fields_by_name['userTokenAuth'].message_type = _USERTOKENAUTH
_AUTHTOKEN.fields_by_name['agentAuth'].message_type = _AGENTAUTH
_AUTHTOKEN.fields_by_name['delegateAuth'].message_type = _DELEGATEAUTH
_AUTHTOKEN.oneofs_by_name['authMechanism'].fields.append(
  _AUTHTOKEN.fields_by_name['userTokenAuth'])
_AUTHTOKEN.fields_by_name['userTokenAuth'].containing_oneof = _AUTHTOKEN.oneofs_by_name['authMechanism']
_AUTHTOKEN.oneofs_by_name['authMechanism'].fields.append(
  _AUTHTOKEN.fields_by_name['agentAuth'])
_AUTHTOKEN.fields_by_name['agentAuth'].containing_oneof = _AUTHTOKEN.oneofs_by_name['authMechanism']
_AUTHTOKEN.oneofs_by_name['authMechanism'].fields.append(
  _AUTHTOKEN.fields_by_name['delegateAuth'])
_AUTHTOKEN.fields_by_name['delegateAuth'].containing_oneof = _AUTHTOKEN.oneofs_by_name['authMechanism']
DESCRIPTOR.message_types_by_name['UserTokenAuth'] = _USERTOKENAUTH
DESCRIPTOR.message_types_by_name['AgentAuth'] = _AGENTAUTH
DESCRIPTOR.message_types_by_name['DelegateAuth'] = _DELEGATEAUTH
DESCRIPTOR.message_types_by_name['AuthToken'] = _AUTHTOKEN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserTokenAuth = _reflection.GeneratedProtocolMessageType('UserTokenAuth', (_message.Message,), {
  'DESCRIPTOR' : _USERTOKENAUTH,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.UserTokenAuth)
  })
_sym_db.RegisterMessage(UserTokenAuth)

AgentAuth = _reflection.GeneratedProtocolMessageType('AgentAuth', (_message.Message,), {
  'DESCRIPTOR' : _AGENTAUTH,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.AgentAuth)
  })
_sym_db.RegisterMessage(AgentAuth)

DelegateAuth = _reflection.GeneratedProtocolMessageType('DelegateAuth', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELEGATEAUTH_PROPERTIESENTRY,
    '__module__' : 'CredCommon_pb2'
    # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _DELEGATEAUTH,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.DelegateAuth)
  })
_sym_db.RegisterMessage(DelegateAuth)
_sym_db.RegisterMessage(DelegateAuth.PropertiesEntry)

AuthToken = _reflection.GeneratedProtocolMessageType('AuthToken', (_message.Message,), {
  'DESCRIPTOR' : _AUTHTOKEN,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.AuthToken)
  })
_sym_db.RegisterMessage(AuthToken)


DESCRIPTOR._options = None
_DELEGATEAUTH_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
